@@ -106,7 +106,7 @@ public:
      * Registering a new collection of a previously registered type forgets the
      * old collection.
      */
-    bool registerCollection(Type type, const Akonadi::Collection &collection);
+    [[nodiscard]] bool registerCollection(Type type, const Akonadi::Collection &collection);
 
     /**
      * Unregisters the given @p collection as a special mail collection
@@ -114,7 +114,7 @@ public:
      * The collection must be owned by a valid resource.
      * @since 4.12
      */
-    bool unregisterCollection(const Collection &collection);
+    [[nodiscard]] bool unregisterCollection(const Collection &collection);
 
     /**
      * Returns whether the default resource has a special mail collection of
